@@ -3,7 +3,7 @@ use std::io;
 use std::io::{BufRead, BufReader};
 use std::path::Path;
 
-use clap::{crate_authors, crate_description, crate_name, crate_version, App, AppSettings, Arg};
+use clap::{crate_authors, crate_description, crate_version, App, AppSettings, Arg};
 
 use lindera::formatter::{format, Format};
 use lindera::tokenizer::{Tokenizer, TokenizerConfig};
@@ -12,7 +12,7 @@ use lindera_core::viterbi::{Mode, Penalty};
 use lindera_core::LinderaResult;
 
 fn main() -> LinderaResult<()> {
-    let app = App::new(crate_name!())
+    let app = App::new("lindera")
         .setting(AppSettings::DeriveDisplayOrder)
         .version(crate_version!())
         .author(crate_authors!())
@@ -36,6 +36,14 @@ fn main() -> LinderaResult<()> {
             .value_name("USER_DICTIONARY")
             .takes_value(true),
         )
+        .arg(
+            Arg::with_name("USER_DICTIONARY_BINARY")
+            .help("(Optional) The user dictionary binary file path.")
+            .short("b")
+            .long("user-dictionary-binary")
+            .value_name("USER_DICTIONARY_BINARY")
+            .takes_value(true),
+        )
         .arg(
             Arg::with_name("MODE")
                 .help("The tokenization mode. `normal` or` search` can be specified. If not specified, use the default mode.")
@@ -69,11 +77,16 @@ fn main() -> LinderaResult<()> {
         config.dict_path = Some(Path::new(dict_dir));
     }
 
-    // user dictionary
+    // user dictionary csv path
     if let Some(user_dict) = matches.value_of("USER_DICTIONARY") {
         config.user_dict_path = Some(Path::new(user_dict));
     }
 
+    // user dictionary binary file path
+    if let Some(user_dict_bin) = matches.value_of("USER_DICTIONARY_BINARY") {
+        config.user_dict_bin_path = Some(Path::new(user_dict_bin));
+    }
+
     // mode
     let mode_name = matches.value_of("MODE").unwrap();
     match mode_name {
